==> kdebindings-3.1.tar.bz2: kdebindings-3.1/qtjava/javalib/examples/hello/Hello.java <==
/***************************************************************************
* $Id: Hello.java,v 1.1 2002/02/26 21:34:41 rdale Exp $
**
* Copyright (C) 1992-2000 Trolltech AS.  All rights reserved.
**
* This file is part of an example program for Qt.  This example
* program may be used, distributed and modified without limitation.
**
****************************************************************************/
import org.kde.qt.*;

class Hello  extends QWidget
{
private    String t;
private    int     b = 0;


/*
  Constructs a Hello widget. Starts a 40 ms animation timer.
*/
Hello( String text )
{
	this(text, null, null);
}

Hello( String text, QWidget parent, String name )
{
    super(parent,name);
	t = text;
    QTimer timer = new QTimer(this);
    connect( timer, SIGNAL("timeout()"), SLOT("animate()") );
    timer.start( 40 );

    resize( 260, 130 );
}


/*
  This private slot is called each time the timer fires.
*/

void animate()
{
    b = (b + 1) & 15;
    repaint( false );
}


/*
  Handles mouse button release events for the Hello widget.

  We emit the clicked() signal when the mouse is released inside
  the widget.
*/

void mouseReleaseEvent( QMouseEvent e )
{
    if ( rect().contains( e.pos() ) )
        emit("clicked");
}


    static int sin_tbl[] = {
        0, 38, 71, 92, 100, 92, 71, 38,	0, -38, -71, -92, -100, -92, -71, -38};

/*
  Handles paint events for the Hello widget.

  Flicker-free update. The text is first drawn in the pixmap and the
  pixmap is then blt'ed to the screen.
*/
void paintEvent( QPaintEvent e )
{
    if ( t.equals("") )
        return;

    // 1: Compute some sizes, positions etc.
    QFontMetrics fm = fontMetrics();
    int w = fm.width(t) + 20;
    int h = fm.height() * 2;
    int pmx = width()/2 - w/2;
    int pmy = height()/2 - h/2;

    // 2: Create the pixmap and fill it with the widget's background
    QPixmap pm = new QPixmap( w, h );
    pm.fill( this, pmx, pmy );

    // 3: Paint the pixmap. Cool wave effect
    QPainter p = new QPainter();
    int x = 10;
    int y = h/2 + fm.descent();
    int i = 0;
    p.begin( pm );
    p.setFont( font() );
    while ( i < t.length() ) {
        int i16 = (b+i) & 15;
        p.setPen( new QColor((15-i16)*16,255,255,QColor.Hsv) );
        p.drawText( x, y-sin_tbl[i16]*h/800, t.substring(i,i+1), 1 );
        x += fm.width( t.substring(i,i+1) );
        i++;
    }
    p.end();

    // 4: Copy the pixmap to the Hello widget
    QPaintDevice.bitBlt( this, pmx, pmy, pm );
}
}

==> kdebindings-3.2.3.tar.bz2: kdebindings-3.2.3/qtjava/javalib/examples/hello/Hello.java <==
/***************************************************************************
* $Id: Hello.java,v 1.2 2003/12/21 05:47:44 rdale Exp $
**
* Copyright (C) 1992-2000 Trolltech AS.  All rights reserved.
**
* This file is part of an example program for Qt.  This example
* program may be used, distributed and modified without limitation.
**
****************************************************************************/
import org.kde.qt.*;

class Hello  extends QWidget
{
private    String t;
private    int     b = 0;


/*
  Constructs a Hello widget. Starts a 40 ms animation timer.
*/
Hello( String text )
{
	this(text, null, null);
}

Hello( String text, QWidget parent, String name )
{
    super(parent,name);
	t = text;
    QTimer timer = new QTimer(this);
    connect( timer, SIGNAL("timeout()"), SLOT("animate()") );
    timer.start( 40 );

    resize( 260, 130 );
}


/*
  This private slot is called each time the timer fires.
*/

void animate()
{
    b = (b + 1) & 15;
    repaint( false );
}


/*
  Handles mouse button release events for the Hello widget.

  We emit the clicked() signal when the mouse is released inside
  the widget.
*/

protected void mouseReleaseEvent( QMouseEvent e )
{
    if ( rect().contains( e.pos() ) )
        emit("clicked");
}


    static int sin_tbl[] = {
        0, 38, 71, 92, 100, 92, 71, 38,	0, -38, -71, -92, -100, -92, -71, -38};

/*
  Handles paint events for the Hello widget.

  Flicker-free update. The text is first drawn in the pixmap and the
  pixmap is then blt'ed to the screen.
*/
protected void paintEvent( QPaintEvent e )
{
    if ( t.equals("") )
        return;

    // 1: Compute some sizes, positions etc.
    QFontMetrics fm = fontMetrics();
    int w = fm.width(t) + 20;
    int h = fm.height() * 2;
    int pmx = width()/2 - w/2;
    int pmy = height()/2 - h/2;

    // 2: Create the pixmap and fill it with the widget's background
    QPixmap pm = new QPixmap( w, h );
    pm.fill( this, pmx, pmy );

    // 3: Paint the pixmap. Cool wave effect
    QPainter p = new QPainter();
    int x = 10;
    int y = h/2 + fm.descent();
    int i = 0;
    p.begin( pm );
    p.setFont( font() );
    while ( i < t.length() ) {
        int i16 = (b+i) & 15;
        p.setPen( new QColor((15-i16)*16,255,255,QColor.Hsv) );
        p.drawText( x, y-sin_tbl[i16]*h/800, t.substring(i,i+1), 1 );
        x += fm.width( t.substring(i,i+1) );
        i++;
    }
    p.end();

    // 4: Copy the pixmap to the Hello widget
    bitBlt( this, pmx, pmy, pm );
}
}
